@@ -7,7 +7,7 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
-#include <hildon-home-plugin/hildon-home-plugin-interface.h>
+#include <libhildondesktop/libhildondesktop.h>
 
 #include "libhelloworld.h"
 
